/* zipios++/zipios-config.h.  Generated automatically by configure.  */
/* zipios++/zipios-config.h.in.  Generated automatically from configure.in by autoheader.  */

/* Define to empty if the keyword does not work.  */
/* #undef const */

/* Define as __inline if that's what the C compiler calls it.  */
/* #undef inline */

/* Define if you have the ANSI C header files.  */
#define STDC_HEADERS 1

/* Define if the std compliant iostream library should be used (if present) */
#define USE_STD_IOSTREAM 1

/* Define if zlib has zError */
#define HAVE_ZERROR 1

/* Define if you have the <unistd.h> header file.  */
#define HAVE_UNISTD_H 1

/* Name of package */
#define PACKAGE "zipios++"

/* Version number of package */
#define VERSION "0.1.5"

/* define if the compiler implements namespaces */
#define HAVE_NAMESPACES 

/* define if the compiler supports Standard Template Library */
#define HAVE_STL 

/* define if the compiler supports ISO C++ standard library */
#define HAVE_STD 

/* define if the compiler has std compliant iostream library */
/* #undef HAVE_STD_IOSTREAM */

